Class: Object
- Inherits:
- BasicObject
- Defined in:
- lib/support/object.rb
Class Method Summary collapse
-
.is_sti? ⇒ Boolean
OPTIMIZE: Probably there’s a better way to verify if a model responds to an STI pattern.
Class Method Details
.is_sti? ⇒ Boolean
OPTIMIZE: Probably there’s a better way to verify if a model responds to an STI pattern.
5 6 7 |
# File 'lib/support/object.rb', line 5 def self.is_sti? (name != base_class.name) && base_class.descends_from_active_record? end |